##  List of Discovered SaaS Applications
The SaaS discovery inbox gives a tabular list of all discovered items. Selecting an item from the list opens a side panel displaying additional details about the selected SaaS. Filtering and search functions enable you to easily refine your view of the listed items.
![List of Discovered SaaS Applications in the Discovery Inbox](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274982867a441014a517e61276a4c68b_LowRes.png)
List of Discovered SaaS Applications in the Discovery Inbox
At the top of the list, overview tiles display the number of items in the inbox in different statuses - Action needed, Linked, Rejected, and Total. These four tiles also act as quick filters. For example, clicking the Action needed tile will remove all current filters and apply the filter to only list items requiring action. Clicking the Total tile will remove all filters, and the list shows all discovered items.
